@@ -5,6 +5,8 @@ from .commands.authenticate_user import AuthenticateUserCommand
 from .commands.register_user import RegisterUserCommand
 from .common.claims import get_claims
 from .common.depends import get_current_user, is_admin, is_enabled, oauth2_scheme
+from .common.jwt import create_access_token, create_user_access_token
+from .common.password import get_password_hash, verify_password
 from .contracts.dto.request_status_codes import RequestStatusCodes
 from .contracts.dto.token import Token
 from .contracts.dto.token_claims import TokenClaims
