@@ -4,8 +4,8 @@ from starlette import status
 
 from rowantree.common.sdk import demand_env_var
 
-from .. import UserBase
 from ..contracts.dto.request_status_codes import RequestStatusCodes
+from ..contracts.dto.user.base import UserBase
 from ..contracts.dto.wrapped_request import WrappedRequest
 from ..contracts.request_verb import RequestVerb
 from ..contracts.requests.register_user_request import RegisterUserRequest
